@@ -2,7 +2,6 @@ package games.strategy.triplea.ui.history;
 
 import games.strategy.engine.history.HistoryNode;
 
-public interface IHistoryDetailsPanel
-{
-	public void render(final HistoryNode node);
+public interface IHistoryDetailsPanel {
+  public void render(final HistoryNode node);
 }
